@@ -22,10 +22,7 @@ import platform
 import struct
 import weakref
 
-try:
-    from xcffib._ffi import ffi
-except ImportError:
-    from xcffib.ffi_build import ffi
+from .ffi import ffi
 
 if platform.system() == "Darwin":
     soname = "libxcb.dylib"
@@ -38,7 +35,7 @@ else:
 lib = ffi.dlopen(soname)
 
 __xcb_proto_version__ = "1.15.2"
-__version__ = "1.2.0"
+__version__ = "1.4.0"
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -59,8 +56,8 @@ XCB_CONN_CLOSED_EXT_NOTSUPPORTED = lib.XCB_CONN_CLOSED_EXT_NOTSUPPORTED
 XCB_CONN_CLOSED_MEM_INSUFFICIENT = lib.XCB_CONN_CLOSED_MEM_INSUFFICIENT
 XCB_CONN_CLOSED_REQ_LEN_EXCEED = lib.XCB_CONN_CLOSED_REQ_LEN_EXCEED
 XCB_CONN_CLOSED_PARSE_ERR = lib.XCB_CONN_CLOSED_PARSE_ERR
-# XCB_CONN_CLOSED_INVALID_SCREEN = lib.XCB_CONN_CLOSED_INVALID_SCREEN
-# XCB_CONN_CLOSED_FDPASSING_FAILED = lib.XCB_CONN_CLOSED_FDPASSING_FAILED
+XCB_CONN_CLOSED_INVALID_SCREEN = lib.XCB_CONN_CLOSED_INVALID_SCREEN
+XCB_CONN_CLOSED_FDPASSING_FAILED = lib.XCB_CONN_CLOSED_FDPASSING_FAILED
 
 cffi_explicit_lifetimes = weakref.WeakKeyDictionary()
 
@@ -456,7 +453,10 @@ class List(Protobj):
         """ A helper for converting a List of chars to a native string. Dies if
         the list contents are not something that could be reasonably converted
         to a string. """
-        return ''.join(chr(i[0]) for i in self)
+        try:
+            return ''.join(chr(i[0]) for i in self)
+        except TypeError:
+            return ''.join(chr(i) for i in self)
 
     def to_utf8(self):
         return b''.join(self).decode('utf-8')
